==> ember-0.5.8.tar.bz2: ember-0.5.8/src/components/ogre/widgets/Performance.lua <==
Performance = {connectors={}}

Performance.widget = guiManager:createWidget()
Performance.mainText = nil

function Performance.buildWidget()
	Performance.widget:loadMainSheet("Performance.layout", "Performance/")
	
	local window = Performance.widget:getWindow("TextBox")
	Performance.mainText = CEGUI.toMultiLineEditbox(window)
	
--	EmberOgre::getSingleton().EventStartErisPoll.connect(sigc::mem_fun(*this, &Performance::startErisPolling));
--	EmberOgre::getSingleton().EventEndErisPoll.connect(sigc::mem_fun(*this, &Performance::endErisPolling));

	connect(Performance.connectors, emberOgre.EventTerrainManagerCreated, "Performance.terrainManagerCreated")
	
	
	
	
	Performance.widget:registerConsoleVisibilityToggleCommand("performance")
	Performance.widget:enableCloseButton()
	Performance.widget:hide()
end

function Performance.terrainManagerCreated(terrainManager)
	Performance.terrainManager = terrainManager
end

function Performance.framestarted(timeSinceLastFrame)
	if (Performance.widget:getMainWindow():isVisible()) then
		local statString
		local stats = emberOgre:getRenderWindow():getStatistics()
		
		--statString = "Current FPS: " .. string.format("%i", stats.lastFPS)
		statString = "FPS: " .. string.format("%i", stats.avgFPS)
		statString = statString .. "\nTriangle count: " .. string.format("%i", stats.triangleCount)
		if app:getMainView() ~= nil then
			statString = statString .. "\nSightqueue: " .. app:getMainView():lookQueueSize()
		end
		local motionInfo = EmberOgre.MotionManager:getSingleton():getInfo()
		statString = statString .. "\nAnimated: " .. motionInfo.AnimatedEntities
		statString = statString .. "\nMoving: " .. motionInfo.MovingEntities
		--ss << "Time in eris: " << getAverageErisTime() * 100 << "% \n"
		
		if Performance.terrainManager ~= nil then
			statString = statString .. "\n" .. Performance.terrainManager:getAdapter():getDebugInfo()
		end
	
		Performance.mainText:setText(statString)
	end

end

Performance.buildWidget()
connect(Performance.connectors, guiManager.EventFrameStarted, "Performance.framestarted")

==> ember-0.6.0.tar.bz2: ember-0.6.0/src/components/ogre/widgets/Performance.lua <==
Performance = {connectors={}}

Performance.widget = guiManager:createWidget()
Performance.mainText = nil

function Performance.buildWidget()
	Performance.widget:loadMainSheet("Performance.layout", "Performance/")
	
	local window = Performance.widget:getWindow("TextBox")
	Performance.mainText = CEGUI.toMultiLineEditbox(window)
	
--	EmberOgre::getSingleton().EventStartErisPoll.connect(sigc::mem_fun(*this, &Performance::startErisPolling));
--	EmberOgre::getSingleton().EventEndErisPoll.connect(sigc::mem_fun(*this, &Performance::endErisPolling));

	connect(Performance.connectors, emberOgre.EventTerrainManagerCreated, Performance.terrainManagerCreated)
	connect(Performance.connectors, emberOgre.EventMotionManagerCreated, Performance.motionManagerCreated)
	connect(Performance.connectors, emberOgre.EventTerrainManagerDestroyed, Performance.terrainManagerDestroyed)
	connect(Performance.connectors, emberOgre.EventMotionManagerDestroyed, Performance.motionManagerDestroyed)
	
	
	connect(Performance.connectors, Performance.widget.EventFrameStarted, Performance.framestarted)
	
	
	Performance.widget:registerConsoleVisibilityToggleCommand("performance")
	Performance.widget:enableCloseButton()
	Performance.widget:hide()
end

function Performance.terrainManagerCreated(terrainManager)
	Performance.terrainManager = terrainManager
end

function Performance.motionManagerCreated(motionManager)
	Performance.motionManager = motionManager
end

function Performance.terrainManagerDestroyed()
	Performance.terrainManager = nil
end

function Performance.motionManagerDestroyed()
	Performance.motionManager = nil
end

function Performance.framestarted(timeSinceLastFrame)
	if (Performance.widget:getMainWindow():isVisible()) then
		local statString
		local stats = emberOgre:getRenderWindow():getStatistics()
		
		--statString = "Current FPS: " .. string.format("%i", stats.lastFPS)
		statString = "FPS: " .. string.format("%i", stats.avgFPS)
		statString = statString .. "\nTriangle count: " .. string.format("%i", stats.triangleCount)
		if app:getMainView() ~= nil then
			statString = statString .. "\nSightqueue: " .. app:getMainView():lookQueueSize()
		end
		if Performance.motionManager then
			local motionInfo = Performance.motionManager:getInfo()
			statString = statString .. "\nAnimated: " .. motionInfo.AnimatedEntities
			statString = statString .. "\nMoving: " .. motionInfo.MovingEntities
		end
		--ss << "Time in eris: " << getAverageErisTime() * 100 << "% \n"
		
		if Performance.terrainManager ~= nil then
			statString = statString .. "\n" .. Performance.terrainManager:getAdapter():getDebugInfo()
		end
	
		Performance.mainText:setText(statString)
	end

end

Performance.buildWidget()
